@@ -38,11 +38,11 @@ class IlmClient(NamespacedClient):
         timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Deletes the specified lifecycle policy definition. You cannot delete policies
-        that are currently in use. If the policy is being used to manage any indices,
-        the request fails and returns an error.
+        Delete a lifecycle policy. You cannot delete policies that are currently in use.
+        If the policy is being used to manage any indices, the request fails and returns
+        an error.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/ilm-delete-lifecycle.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/ilm-delete-lifecycle.html>`_
 
         :param name: Identifier for the policy.
         :param master_timeout: Period to wait for a connection to the master node. If
@@ -93,11 +93,13 @@ class IlmClient(NamespacedClient):
         timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Retrieves information about the index’s current lifecycle state, such as the
-        currently executing phase, action, and step. Shows when the index entered each
-        one, the definition of the running phase, and information about any failures.
+        Explain the lifecycle state. Get the current lifecycle status for one or more
+        indices. For data streams, the API retrieves the current lifecycle status for
+        the stream's backing indices. The response indicates when the index entered each
+        lifecycle state, provides the definition of the running phase, and information
+        about any failures.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/ilm-explain-lifecycle.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/ilm-explain-lifecycle.html>`_
 
         :param index: Comma-separated list of data streams, indices, and aliases to target.
             Supports wildcards (`*`). To target all data streams and indices, use `*`
@@ -157,9 +159,9 @@ class IlmClient(NamespacedClient):
         timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Retrieves a lifecycle policy.
+        Get lifecycle policies.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/ilm-get-lifecycle.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/ilm-get-lifecycle.html>`_
 
         :param name: Identifier for the policy.
         :param master_timeout: Period to wait for a connection to the master node. If
@@ -208,9 +210,9 @@ class IlmClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Retrieves the current index lifecycle management (ILM) status.
+        Get the ILM status. Get the current index lifecycle management status.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/ilm-get-status.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/ilm-get-status.html>`_
         """
         __path_parts: t.Dict[str, str] = {}
         __path = "/_ilm/status"
@@ -249,12 +251,20 @@ class IlmClient(NamespacedClient):
         body: t.Optional[t.Dict[str, t.Any]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Switches the indices, ILM policies, and legacy, composable and component templates
-        from using custom node attributes and attribute-based allocation filters to using
-        data tiers, and optionally deletes one legacy index template.+ Using node roles
-        enables ILM to automatically move the indices between data tiers.
+        Migrate to data tiers routing. Switch the indices, ILM policies, and legacy,
+        composable, and component templates from using custom node attributes and attribute-based
+        allocation filters to using data tiers. Optionally, delete one legacy index template.
+        Using node roles enables ILM to automatically move the indices between data tiers.
+        Migrating away from custom node attributes routing can be manually performed.
+        This API provides an automated way of performing three out of the four manual
+        steps listed in the migration guide: 1. Stop setting the custom hot attribute
+        on new indices. 1. Remove custom allocation settings from existing ILM policies.
+        1. Replace custom allocation settings from existing indices with the corresponding
+        tier preference. ILM must be stopped before performing the migration. Use the
+        stop ILM and get ILM status APIs to wait until the reported operation mode is
+        `STOPPED`.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/ilm-migrate-to-data-tiers.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/ilm-migrate-to-data-tiers.html>`_
 
         :param dry_run: If true, simulates the migration from node attributes based allocation
             filters to data tiers, but does not perform the migration. This provides
@@ -304,24 +314,42 @@ class IlmClient(NamespacedClient):
         *,
         index: str,
         current_step: t.Optional[t.Mapping[str, t.Any]] = None,
+        next_step: t.Optional[t.Mapping[str, t.Any]] = None,
         error_trace: t.Optional[bool] = None,
         filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         human: t.Optional[bool] = None,
-        next_step: t.Optional[t.Mapping[str, t.Any]] = None,
         pretty: t.Optional[bool] = None,
         body: t.Optional[t.Dict[str, t.Any]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Manually moves an index into the specified step and executes that step.
+        Move to a lifecycle step. Manually move an index into a specific step in the
+        lifecycle policy and run that step. WARNING: This operation can result in the
+        loss of data. Manually moving an index into a specific step runs that step even
+        if it has already been performed. This is a potentially destructive action and
+        this should be considered an expert level API. You must specify both the current
+        step and the step to be executed in the body of the request. The request will
+        fail if the current step does not match the step currently running for the index
+        This is to prevent the index from being moved from an unexpected step into the
+        next step. When specifying the target (`next_step`) to which the index will be
+        moved, either the name or both the action and name fields are optional. If only
+        the phase is specified, the index will move to the first step of the first action
+        in the target phase. If the phase and action are specified, the index will move
+        to the first step of the specified action in the specified phase. Only actions
+        specified in the ILM policy are considered valid. An index cannot move to a step
+        that is not part of its policy.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/ilm-move-to-step.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/ilm-move-to-step.html>`_
 
         :param index: The name of the index whose lifecycle step is to change
-        :param current_step:
-        :param next_step:
+        :param current_step: The step that the index is expected to be in.
+        :param next_step: The step that you want to run.
         """
         if index in SKIP_IN_PATH:
             raise ValueError("Empty value passed for parameter 'index'")
+        if current_step is None and body is None:
+            raise ValueError("Empty value passed for parameter 'current_step'")
+        if next_step is None and body is None:
+            raise ValueError("Empty value passed for parameter 'next_step'")
         __path_parts: t.Dict[str, str] = {"index": _quote(index)}
         __path = f'/_ilm/move/{__path_parts["index"]}'
         __query: t.Dict[str, t.Any] = {}
@@ -371,10 +399,11 @@ class IlmClient(NamespacedClient):
         body: t.Optional[t.Dict[str, t.Any]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Creates a lifecycle policy. If the specified policy exists, the policy is replaced
-        and the policy version is incremented.
+        Create or update a lifecycle policy. If the specified policy exists, it is replaced
+        and the policy version is incremented. NOTE: Only the latest version of the policy
+        is stored, you cannot revert to previous versions.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/ilm-put-lifecycle.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/ilm-put-lifecycle.html>`_
 
         :param name: Identifier for the policy.
         :param master_timeout: Period to wait for a connection to the master node. If
@@ -431,9 +460,10 @@ class IlmClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Removes the assigned lifecycle policy and stops managing the specified index
+        Remove policies from an index. Remove the assigned lifecycle policies from an
+        index or a data stream's backing indices. It also stops managing the indices.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/ilm-remove-policy.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/ilm-remove-policy.html>`_
 
         :param index: The name of the index to remove policy on
         """
@@ -471,9 +501,12 @@ class IlmClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Retries executing the policy for an index that is in the ERROR step.
+        Retry a policy. Retry running the lifecycle policy for an index that is in the
+        ERROR step. The API sets the policy back to the step where the error occurred
+        and runs the step. Use the explain lifecycle state API to determine whether an
+        index is in the ERROR step.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/ilm-retry-policy.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/ilm-retry-policy.html>`_
 
         :param index: The name of the indices (comma-separated) whose failed lifecycle
             step is to be retry
@@ -513,12 +546,14 @@ class IlmClient(NamespacedClient):
         timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Start the index lifecycle management (ILM) plugin.
+        Start the ILM plugin. Start the index lifecycle management plugin if it is currently
+        stopped. ILM is started automatically when the cluster is formed. Restarting
+        ILM is necessary only when it has been stopped using the stop ILM API.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/ilm-start.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/ilm-start.html>`_
 
-        :param master_timeout:
-        :param timeout:
+        :param master_timeout: Explicit operation timeout for connection to master node
+        :param timeout: Explicit operation timeout
         """
         __path_parts: t.Dict[str, str] = {}
         __path = "/_ilm/start"
@@ -557,13 +592,17 @@ class IlmClient(NamespacedClient):
         timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Halts all lifecycle management operations and stops the index lifecycle management
-        (ILM) plugin
+        Stop the ILM plugin. Halt all lifecycle management operations and stop the index
+        lifecycle management plugin. This is useful when you are performing maintenance
+        on the cluster and need to prevent ILM from performing any actions on your indices.
+        The API returns as soon as the stop request has been acknowledged, but the plugin
+        might continue to run until in-progress operations complete and the plugin can
+        be safely stopped. Use the get ILM status API to check whether ILM is running.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/ilm-stop.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/ilm-stop.html>`_
 
-        :param master_timeout:
-        :param timeout:
+        :param master_timeout: Explicit operation timeout for connection to master node
+        :param timeout: Explicit operation timeout
         """
         __path_parts: t.Dict[str, str] = {}
         __path = "/_ilm/stop"
